@@ -25,7 +25,7 @@ in a web interface.
 
 This file write HTML documentation using pydoc."""
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -49,7 +49,7 @@ __copyright__ = copyright
 __all__ = []
 
 from pydoc import resolve, html, describe, ErrorDuringImport
-from os import path, getcwd, chdir
+from os import path, chdir
 import sys
 
 # chdir(path.join(path.dirname(__file__), "..", ".."))
@@ -60,14 +60,12 @@ def main() -> None:
     """This file write HTML documentation using pydoc."""
 
     if len(sys.argv) != 2:
-        print(
-            "USAGE: py_doc.py [filename string required]"
-        )
+        print("USAGE: py_doc.py [filename string required]")
         sys.exit(1)
 
     COLORS = {
         "#ffc8d8": "#EEC477",
-#        "#ee77aa": "#A57927",
+        #        "#ee77aa": "#A57927",
         "#ee77aa": "#C89B48",
         "#aa55cc": "#4A948C",
     }
@@ -86,7 +84,7 @@ def main() -> None:
             page = page.replace(f'bgcolor="{old_color}"', f'bgcolor="{new_color}"')
 
         # filename = path.join(getcwd(), "documentation", name)
-        filename = path.join(getcwd(), "doc", name)
+        filename = path.join(path.dirname(__file__), "..", "..", "doc", name)
 
         with open(f"{filename}.html", "w", encoding="utf-8") as file:
             file.write(page)
